pyxmpp2.xmppparser.XMLStreamHandler

Package pyxmpp2 :: Module xmppparser :: Class XMLStreamHandler |
[hide private]

# Class XMLStreamHandler

Base class for stream handler, used as a target for XMPP parser or XMPP transports.

Instance Methods | [hide private]
stream_start(self, element) Called when the start tag of root element is encountered in the stream. |
stream_end(self) Called when the end tag of root element is encountered in the stream. |
stream_element(self, element) Called when the end tag of a direct child of the root element is encountered in the stream. |
stream_parse_error(self, descr) Called when an error is encountered in the stream. |
stream_eof(self) Called when stream input ends (EOF, socket closed by peer) which could happen before actual stream end tag was received, but usually will happen just after that. |
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### stream_start(self, element) |
Called when the start tag of root element is encountered in the stream. Parameters: `element` (`ElementTree.Element`) - the root element

### stream_element(self, element) |
Called when the end tag of a direct child of the root element is encountered in the stream. Parameters: `element` (`ElementTree.Element`) - the (complete) element being processed

### stream_parse_error(self, descr) |
Called when an error is encountered in the stream. Parameters: `descr` (`unicode`) - description of the error

### stream_eof(self) |
Called when stream input ends (EOF, socket closed by peer) which could happen before actual stream end tag was received, but usually will happen just after that. This event is not generated by the XMPP parser, but may be generated by transports.